==> nextcloud-26.0.10.tgz: nextcloud/apps/systemtags/l10n/es_EC.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Etiqueta del sistema %1$s agregada por el sistema",
    "Added system tag {systemtag}" : "Etiqueta del sistema {systemtag} agregada",
    "Added system tag %1$s" : "Etiqueta del sistema %1$s agregada",
    "%1$s added system tag %2$s" : "%1$s agregó la etiqueta del sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} agregó la etiqueta del sistema {systemtag}",
    "System tag %1$s removed by the system" : "Etiqueta del sistema %1$s eliminada por el sistema",
    "Removed system tag {systemtag}" : "Eliminó la etiqueta del sistema {systemtag}",
    "Removed system tag %1$s" : "Etiqueta del sistema %1$s eliminada",
    "%1$s removed system tag %2$s" : "%1$s eliminó la etiqueta del sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} eliminó la etiqueta del sistema {systemtag}",
    "You created system tag %1$s" : "Creaste la etiqueta del sistema %1$s",
    "You created system tag {systemtag}" : "Creaste la etiqueta del sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creo la etiqueta del sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creó la etiqueta del sistema {systemtag}",
    "You deleted system tag %1$s" : "Borraste la etiqueta del sistema %1$s",
    "You deleted system tag {systemtag}" : "Borraste la etiqueta del sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s borró la etiqueta del sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} borró la etiqueta del sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Actualizaste la etiqueta del sistema %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Actualizaste la etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s actualizó la etiqueta del sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} actualizó la etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Etiqueta del sistema %2$s fue agregada a %1$s por el sistema",
    "System tag {systemtag} was added to {file} by the system" : "Etiqueta del sistema {systemtag} fue agregada a {file} por el sistema",
    "You added system tag %2$s to %1$s" : "Agregaste la etiqueta del sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Agregaste la etiqueta del sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s agregó la etiqueta del sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} agregó la etiqueta del sistema {systemtag} a {file}",
    "System tag %2$s was removed from %1$s by the system" : "Etiqueta del sistema %2$s fue eliminada de %1$s por el sistema",
    "System tag {systemtag} was removed from {file} by the system" : "Etiqueta del sistema {systemtag} fue eliminada de {file} por el sistema",
    "You removed system tag %2$s from %1$s" : "Eliminaste la etiqueta del sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Eliminaste la etiqueta del sistema {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s eliminó la etiqueta del sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} eliminó la etiqueta del sistema  {systemtag} de {file}",
    "%s (restricted)" : "%s (restringido)",
    "%s (invisible)" : "%s (invisible) ",
    "<strong>System tags</strong> for a file have been modified" : "Las <strong>etiquetas del sistema</strong> para un archivo han sido modificadas",
    "Tags" : "Etiquetas",
    "All tagged %s …" : "Todas las etiquetas de %s...",
    "tagged %s" : "etiquetadas %s",
    "Collaborative tags" : "Etiquetas colaborativas",
    "Collaborative tagging functionality which shares tags among users." : "Funcionalidad de etiquetado colaborativo que comparte etiquetas entre usuarios.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidad de etiquetado colaborativo que comparte etiquetas entre usuarios. Ideal para equipos.\n        (Si eres un proveedor con una instalación de múltiples inquilinos, se recomienda desactivar esta aplicación, ya que las etiquetas se comparten.)",
    "Collaborative tags …" : "Etiquetas colaborativas...",
    "Create" : "Crear",
    "Update" : "Actualizar",
    "Delete" : "Borrar",
    "Reset" : "Restaurar",
    "Loading …" : "Cargando...",
    "Public" : "Público",
    "Restricted" : "Restringido",
    "Invisible" : "Invisible",
    "Failed to create tag" : "Error al crear la etiqueta",
    "Failed to delete tag" : "Error al eliminar la etiqueta",
    "Loading collaborative tags …" : "Cargando etiquetas colaborativas...",
    "Search or create collaborative tags" : "Buscar o crear etiquetas colaborativas",
    "No tags to select, type to create a new tag" : "No hay etiquetas para seleccionar, escribe para crear una nueva etiqueta",
    "Failed to load tags" : "Error al cargar las etiquetas",
    "Failed to load selected tags" : "Error al cargar las etiquetas seleccionadas",
    "Failed to select tag" : "Error al seleccionar la etiqueta",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Las etiquetas colaborativas están disponibles para todos los usuarios. Las etiquetas restringidas son visibles para los usuarios, pero no pueden asignarlas. Las etiquetas invisibles son para uso interno, ya que los usuarios no pueden verlas ni asignarlas.",
    "This file has the tag {tag}" : "Este archivo tiene la etiqueta {tag}.",
    "This file has the tags {firstTags} and {lastTag}" : "Este archivo tiene las etiquetas {firstTags} y {lastTag}.",
    "No tags found" : "No se encontraron etiquetas",
    "Failed to load last used tags" : "Error al cargar las últimas etiquetas utilizadas",
    "Missing \"Content-Location\" header" : "Falta el encabezado \"Content-Location\"",
    "No files in here" : "No hay archivos aquí",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "Tag name is empty" : "El nombre de la etiqueta está vacío",
    "Select tag …" : "Seleccionar etiqueta ...",
    "Tagged files" : "Archivos etiquetados",
    "Select tags to filter by" : "Selecciona las etiquetas del filtro",
    "Please select tags to filter by" : "Por favor selecciona las etiquetas del filtro",
    "No files found for the selected tags" : "No se encontraron archivos para las etiquetas seleccionadas",
    "Create a new tag" : "Crear una nueva etiqueta"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-28.0.3.tgz: nextcloud/apps/systemtags/l10n/es_EC.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Etiqueta del sistema %1$s agregada por el sistema",
    "Added system tag {systemtag}" : "Etiqueta del sistema {systemtag} agregada",
    "Added system tag %1$s" : "Etiqueta del sistema %1$s agregada",
    "%1$s added system tag %2$s" : "%1$s agregó la etiqueta del sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} agregó la etiqueta del sistema {systemtag}",
    "System tag %1$s removed by the system" : "Etiqueta del sistema %1$s eliminada por el sistema",
    "Removed system tag {systemtag}" : "Eliminó la etiqueta del sistema {systemtag}",
    "Removed system tag %1$s" : "Etiqueta del sistema %1$s eliminada",
    "%1$s removed system tag %2$s" : "%1$s eliminó la etiqueta del sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} eliminó la etiqueta del sistema {systemtag}",
    "You created system tag %1$s" : "Creaste la etiqueta del sistema %1$s",
    "You created system tag {systemtag}" : "Creaste la etiqueta del sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creo la etiqueta del sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creó la etiqueta del sistema {systemtag}",
    "You deleted system tag %1$s" : "Borraste la etiqueta del sistema %1$s",
    "You deleted system tag {systemtag}" : "Borraste la etiqueta del sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s borró la etiqueta del sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} borró la etiqueta del sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Actualizaste la etiqueta del sistema %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Actualizaste la etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s actualizó la etiqueta del sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} actualizó la etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Etiqueta del sistema %2$s fue agregada a %1$s por el sistema",
    "System tag {systemtag} was added to {file} by the system" : "Etiqueta del sistema {systemtag} fue agregada a {file} por el sistema",
    "You added system tag %2$s to %1$s" : "Agregaste la etiqueta del sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Agregaste la etiqueta del sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s agregó la etiqueta del sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} agregó la etiqueta del sistema {systemtag} a {file}",
    "System tag %2$s was removed from %1$s by the system" : "Etiqueta del sistema %2$s fue eliminada de %1$s por el sistema",
    "System tag {systemtag} was removed from {file} by the system" : "Etiqueta del sistema {systemtag} fue eliminada de {file} por el sistema",
    "You removed system tag %2$s from %1$s" : "Eliminaste la etiqueta del sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Eliminaste la etiqueta del sistema {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s eliminó la etiqueta del sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} eliminó la etiqueta del sistema  {systemtag} de {file}",
    "%s (restricted)" : "%s (restringido)",
    "%s (invisible)" : "%s (invisible) ",
    "<strong>System tags</strong> for a file have been modified" : "Las <strong>etiquetas del sistema</strong> para un archivo han sido modificadas",
    "Tags" : "Etiquetas",
    "All tagged %s …" : "Todas las etiquetas de %s...",
    "tagged %s" : "etiquetadas %s",
    "Collaborative tags" : "Etiquetas colaborativas",
    "Collaborative tags …" : "Etiquetas colaborativas...",
    "Create" : "Crear",
    "Update" : "Actualizar",
    "Delete" : "Borrar",
    "Reset" : "Restaurar",
    "Loading …" : "Cargando...",
    "Public" : "Público",
    "Restricted" : "Restringido",
    "Invisible" : "Invisible",
    "Failed to create tag" : "Error al crear la etiqueta",
    "Failed to delete tag" : "Error al eliminar la etiqueta",
    "Loading collaborative tags …" : "Cargando etiquetas colaborativas...",
    "Search or create collaborative tags" : "Buscar o crear etiquetas colaborativas",
    "No tags to select, type to create a new tag" : "No hay etiquetas para seleccionar, escribe para crear una nueva etiqueta",
    "Failed to load tags" : "Error al cargar las etiquetas",
    "Failed to load selected tags" : "Error al cargar las etiquetas seleccionadas",
    "Failed to select tag" : "Error al seleccionar la etiqueta",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Las etiquetas colaborativas están disponibles para todos los usuarios. Las etiquetas restringidas son visibles para los usuarios, pero no pueden asignarlas. Las etiquetas invisibles son para uso interno, ya que los usuarios no pueden verlas ni asignarlas.",
    "This file has the tag {tag}" : "Este archivo tiene la etiqueta {tag}.",
    "This file has the tags {firstTags} and {lastTag}" : "Este archivo tiene las etiquetas {firstTags} y {lastTag}.",
    "No tags found" : "No se encontraron etiquetas",
    "Failed to load last used tags" : "Error al cargar las últimas etiquetas utilizadas",
    "Missing \"Content-Location\" header" : "Falta el encabezado \"Content-Location\"",
    "Tag name is empty" : "El nombre de la etiqueta está vacío",
    "Select tag …" : "Seleccionar etiqueta ...",
    "Collaborative tagging functionality which shares tags among users." : "Funcionalidad de etiquetado colaborativo que comparte etiquetas entre usuarios.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidad de etiquetado colaborativo que comparte etiquetas entre usuarios. Ideal para equipos.\n        (Si eres un proveedor con una instalación de múltiples inquilinos, se recomienda desactivar esta aplicación, ya que las etiquetas se comparten.)",
    "Tagged files" : "Archivos etiquetados",
    "Select tags to filter by" : "Selecciona las etiquetas del filtro",
    "Please select tags to filter by" : "Por favor selecciona las etiquetas del filtro",
    "No files found for the selected tags" : "No se encontraron archivos para las etiquetas seleccionadas",
    "Create a new tag" : "Crear una nueva etiqueta",
    "Name" : "Nombre",
    "No files in here" : "No hay archivos aquí",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Size" : "Tamaño",
    "Modified" : "Modificado"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
